==> ansela_0.3-4.tar.gz: ansela-0.3/src/opt/anselA/ui/AnselA_Core.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
import os
from PIL import Image
from PyQt4 import QtGui
from PyQt4 import QtCore 
from PyQt4.QtGui import QMainWindow
from PyQt4.QtCore import pyqtSignature

def Enhance(self, im, name, lo, hi):
# set up the image
    im=curIm
    self.enhancer = enhancer(im)
    self.update("1.0") # normalize

    self.value = eval(value)
    
def MinMax():
    if (self.isFullScreen):
        self.showFullScreen()
    else:
        self.showNormal()

def pil2qpixmap(pil_image):
    w, h = pil_image.size
    data = pil_image.tostring("raw", "BGRX")
    qimage = QtGui.QImage(data, w, h, QtGui.QImage.Format_RGB32)
    qpixmap = QtGui.QPixmap(w,h)
    pix = QtGui.QPixmap.fromImage(qimage)
    return pix

def valToScalar(value): #, soft):
    """
    Calculates an appropiate value to scale from / to
    """
    if (value >0):
        return 1+value/20.0
    if (value <0):
        return 1+(value*0.01)
    if (value ==0):
        return 1


class ParamValues():
    def __init__(self):
        self.valR = 0
        self.valB = 0
        self.valG = 0
        self.valSa = 0
        self.valBr = 0
        self.valCo = 0
        self.valHi =0
        self.valMi =0
        self.valSh =0
        self.valSa =0
        self.valRot = 0
        self.valOrient = 0
        self.valBW = "L"
        self.wMaximized = True
        self.lockUpdating = False
        self.curImageLoc =os.getcwd()+"/ui/resources/landscapeRepo.jpg"
        self.plotIm = Image.open(os.getcwd()+"/ui/resources/graph.png") 
        self.curIm =""
        self.curThumb = ""
        self.origIm = ""
        self.valCurTab=0
        self.ApplyVisible = True #Leave true so Init_ can hide
        
        #if __name__ == '__main__':

==> ansela_0.3-5.tar.gz: ansela-0.3/src/opt/anselA/ui/AnselA_Core.py <==
# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
import os
from PIL import Image
from PyQt4 import QtGui
from PyQt4 import QtCore 
from PyQt4.QtGui import QMainWindow
from PyQt4.QtCore import pyqtSignature

def Enhance(self, im, name, lo, hi):
# set up the image
    im=curIm
    self.enhancer = enhancer(im)
    self.update("1.0") # normalize

    self.value = eval(value)
    
def MinMax():
    if (self.isFullScreen):
        self.showFullScreen()
    else:
        self.showNormal()

def pil2qpixmap(pil_image):
    w, h = pil_image.size
    data = pil_image.tostring("raw", "BGRX")
    qimage = QtGui.QImage(data, w, h, QtGui.QImage.Format_RGB32)
    qpixmap = QtGui.QPixmap(w,h)
    pix = QtGui.QPixmap.fromImage(qimage)
    return pix

def valToScalar(value): #, soft):
    """
    Calculates an appropiate value to scale from / to
    """
    if (value >0):
        return 1+value/20.0
    if (value <0):
        return 1+(value*0.01)
    if (value ==0):
        return 1


class ParamValues():
    def __init__(self):
        self.valR = 0
        self.valB = 0
        self.valG = 0
        self.valSa = 0
        self.valBr = 0
        self.valCo = 0
        self.valHi =0
        self.valMi =0
        self.valSh =0
        self.valSa =0
        self.valRot = 0
        self.valOrient = 0
        self.valBW = "L"
        self.wMaximized = True
        self.lockUpdating = False
        self.curImageLoc ="/opt/anselA/ui/resources/landscapeRepo.jpg"
        self.plotIm = Image.open("/opt/anselA/ui/resources/graph.png") 
        self.curIm =""
        self.curThumb = ""
        self.origIm = ""
        self.valCurTab=0
        self.ApplyVisible = True #Leave true so Init_ can hide
        
        #if __name__ == '__main__':
